@@ -79,6 +79,14 @@ async def meta_api_synchronization():
         await connection.subscribe_to_market_data('EURUSD')
         print('EURUSD price:', terminal_state.price('EURUSD'))
 
+        # calculate margin required for trade
+        print('margin required for trade', await connection.calculate_margin({
+            'symbol': 'GBPUSD',
+            'type': 'ORDER_TYPE_BUY',
+            'volume': 0.1,
+            'openPrice': 1.1
+        }))
+
         # trade
         print('Submitting pending order')
         try:
